@@ -6,7 +6,7 @@ use warnings;
 use Perl::Critic::Utils qw(:severities :classification :ppi);
 use parent 'Perl::Critic::Policy';
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use constant DESC => 'open() called with less than 3 arguments';
 use constant EXPL => 'The one- and two-argument forms of open() parse functionality from the filename, use the three-argument form instead.';
@@ -21,7 +21,11 @@ sub violates {
 	return () unless $elem eq 'open' and is_function_call $elem;
 	
 	my @args = parse_arg_list $elem;
-	return $self->violation(DESC, EXPL, $elem) if @args < 3;
+	if (@args < 3) {
+		return () if @args == 2 and $args[1][0]->isa('PPI::Token::Quote')
+			and $args[1][0]->string =~ /^(?:-\||\|-)\z/;
+		return $self->violation(DESC, EXPL, $elem);
+	}
 	
 	return ();
 }
@@ -47,6 +51,10 @@ argument, so it is always distinct from the filename.
   open my $fh, "<$filename";   # not ok
   open my $fh, '<', $filename; # ok
 
+This policy is similar to the core policy
+L<Perl::Critic::Policy::InputOutput::ProhibitTwoArgOpen>, but additionally
+prohibits one-argument opens.
+
 =head1 AFFILIATION
 
 This policy is part of L<Perl::Critic::Freenode>.
